@@ -11,14 +11,15 @@ use strict;
 use warnings;
 
 package Dist::Zilla::PluginBundle::Author::RWSTAUNER;
-# git description: v4.202-4-gffdef5a
+# git description: v4.203-7-g5afccdb
 
 our $AUTHORITY = 'cpan:RWSTAUNER';
-$Dist::Zilla::PluginBundle::Author::RWSTAUNER::VERSION = '4.203';
+$Dist::Zilla::PluginBundle::Author::RWSTAUNER::VERSION = '4.204';
 # ABSTRACT: RWSTAUNER's Dist::Zilla config
 
 use Moose;
 use List::Util qw(first); # core
+use Moose::Util::TypeConstraints 1.01;
 
 with qw(
   Dist::Zilla::Role::PluginBundle::Easy
@@ -42,59 +43,146 @@ sub _bundle_name {
   join('', '@', ($class =~ /^.+::PluginBundle::(.+)$/));
 }
 
-# TODO: consider an option for using ReportPhase
-sub _default_attributes {
-  use Moose::Util::TypeConstraints 1.01;
-  return {
-    auto_prereqs    => [Bool => 1],
-    fake_release    => [Bool => $ENV{DZIL_FAKERELEASE}],
-    # cpanm will choose the best place to install
-    install_command => [Str  => 'cpanm -v -i .'],
-    is_task         => [Bool => 0],
-    open_source     => [Bool => 1],
-    placeholder_comments => [Bool => 0],
-    skip_plugins    => [Str  => ''],
-    weaver_config   => [Str  => $_[0]->_bundle_name],
-    use_git_bundle  => [Bool => 1],
-    max_target_perl => [Str  => '5.008'],
-    builder         => [enum( [ both => keys %builders ] ) => 'eumm'],
-  };
+sub mvp_multivalue_args { qw(
+  copy_files
+) }
+
+sub _config {
+  my ($self, $key, $default) = @_;
+  exists $self->payload->{$key} ? $self->payload->{$key} : $default;
 }
 
-sub _generate_attribute {
-  my ($self, $key) = @_;
-  has $key => (
-    is      => 'ro',
-    isa     => $self->_default_attributes->{$key}[0],
-    lazy    => 1,
-    default => sub {
-      # if it exists in the payload
-      exists $_[0]->payload->{$key}
-        # use it
-        ?  $_[0]->payload->{$key}
-        # else get it from the defaults (for subclasses)
-        :  $_[0]->_default_attributes->{$key}[1];
-    }
-  );
+has authority => (
+  is         => 'ro',
+  isa        => 'Str',
+  lazy       => 1,
+  default    => sub {
+    $_[0]->_config(authority => $_[0]->_default_authority);
+  },
+);
+
+sub _default_authority {
+  (ref($_[0]) || $_[0]) =~ /Author::(\w+)/ ? 'cpan:'.$1 : undef;
 }
 
+has auto_prereqs => (
+  is         => 'ro',
+  isa        => 'Bool',
+  lazy       => 1,
+  default    => sub {
+    $_[0]->_config(auto_prereqs => 1);
+  }
+);
+
+has builder => (
+  is         => 'ro',
+  isa        => enum( [ both => keys %builders ] ),
+  lazy       => 1,
+  default    => sub {
+    $_[0]->_config(builder => 'eumm');
+  }
+);
+
+has copy_files => (
+  is         => 'ro',
+  isa        => 'ArrayRef[Str]',
+  lazy       => 1,
+  default    => sub {
+    [ qw( LICENSE ),
+      map { /(\S+)/g } @{ $_[0]->_config(copy_files => []) } ]
+  },
+);
+
+has fake_release => (
+  is         => 'ro',
+  isa        => 'Bool',
+  lazy       => 1,
+  default    => sub {
+    $_[0]->_config(fake_release => $ENV{DZIL_FAKERELEASE});
+  }
+);
+
+has install_command => (
+  is         => 'ro',
+  isa        => 'Str',
+  lazy       => 1,
+  default    => sub {
+    # cpanm will choose the best place to install
+    $_[0]->_config(install_command => 'cpanm -v -i .');
+  }
+);
+
+has is_task => (
+  is         => 'ro',
+  isa        => 'Bool',
+  lazy       => 1,
+  default    => sub {
+    $_[0]->_config(is_task => 0);
+  }
+);
+
+has max_target_perl => (
+  is         => 'ro',
+  isa        => 'Str',
+  lazy       => 1,
+  default    => sub {
+    $_[0]->_config(max_target_perl => '5.008');
+  }
+);
+
+has open_source => (
+  is         => 'ro',
+  isa        => 'Bool',
+  lazy       => 1,
+  default    => sub {
+    $_[0]->_config(open_source => 1);
+  }
+);
+
+has placeholder_comments => (
+  is         => 'ro',
+  isa        => 'Bool',
+  lazy       => 1,
+  default    => sub {
+    $_[0]->_config(placeholder_comments => 0);
+  }
+);
+
 has releaser => (
   is         => 'ro',
   isa        => 'Str',
   lazy       => 1,
   default    => sub {
-    my ($self) = @_;
-    exists $self->payload->{releaser}
-      ?    $self->payload->{releaser}
-      :    $self->open_source ? 'UploadToCPAN' : '';
+    $_[0]->_config('releaser', $_[0]->open_source ? 'UploadToCPAN' : '');
   },
 );
 
-{
-  # generate attributes
-  __PACKAGE__->_generate_attribute($_)
-    for keys %{ __PACKAGE__->_default_attributes };
-}
+has skip_plugins => (
+  is         => 'ro',
+  isa        => 'Str',
+  lazy       => 1,
+  default    => sub {
+    $_[0]->_config(skip_plugins => '');
+  }
+);
+
+has use_git_bundle => (
+  is         => 'ro',
+  isa        => 'Bool',
+  lazy       => 1,
+  default    => sub {
+    $_[0]->_config(use_git_bundle => 1);
+  }
+);
+
+has weaver_config => (
+  is         => 'ro',
+  isa        => 'Str',
+  lazy       => 1,
+  default    => sub {
+    $_[0]->_config(weaver_config => $_[0]->_bundle_name);
+  }
+);
 
 around BUILDARGS => sub {
   my ($orig, $class, @args) = @_;
@@ -113,7 +201,7 @@ around BUILDARGS => sub {
   return $attr;
 };
 
-# main
+# Alter configuration after setup.
 after configure => sub {
   my ($self) = @_;
 
@@ -156,6 +244,7 @@ after configure => sub {
   }
 };
 
+# Configure plugins.
 sub configure {
   my ($self) = @_;
 
@@ -194,6 +283,7 @@ sub configure {
     [
       Authority => {
         ':version'     => '1.005', # accepts any non-whitespace + locate_comment
+        authority      => $self->authority,
         do_munging     => 1,
         do_metadata    => 1,
         locate_comment => $self->placeholder_comments,
@@ -229,13 +319,15 @@ sub configure {
 
   $self->add_plugins(
     [
-      # generate README.pod in repo root for github
+      # Generate README in repo root for github.
       ReadmeAnyFromPod => {
-        ':version' => '0.120120',
-        type       => 'markdown',
+        ':version' => '0.142180', # 'phase'
+        type       => 'markdown', # L<> to metacpan
         location   => 'root',
+        phase      => 'release',
       }
     ],
+    [ CopyFilesFromRelease => { filename => $self->copy_files } ],
 
   # metadata
     [
@@ -379,7 +471,10 @@ sub configure {
   # defaults: { tag_format => '%v', push_to => [ qw(origin) ] }
   $self->add_bundle('@Git' => {
     ':version' => '2.004', # improved changelog parsing
-    allow_dirty => [qw(Changes README.mkdn README.pod)],
+    allow_dirty => [
+      qw(Changes README.mkdn README.pod),
+      @{ $self->copy_files }
+    ],
     commit_msg  => 'v%v%t%n%n%c'
   })
     if $self->use_git_bundle;
@@ -454,7 +549,7 @@ Dist::Zilla::PluginBundle::Author::RWSTAUNER - RWSTAUNER's Dist::Zilla config
 
 =head1 VERSION
 
-version 4.203
+version 4.204
 
 =head1 SYNOPSIS
 
@@ -475,8 +570,10 @@ log log_fatal
 
 Possible options and their default values:
 
+  authority      = cpan:RWSTAUNER
   auto_prereqs   = 1  ; enable AutoPrereqs
   builder        = eumm ; or 'mb' or 'both'
+  copy_files     =    ; space-separated list of additional files to copy from build
   fake_release   = 0  ; if true will use FakeRelease instead of 'releaser'
   install_command = cpanm -v -i . (passed to InstallRelease)
   is_task        = 0  ; set to true to use TaskWeaver instead of PodWeaver
@@ -561,6 +658,7 @@ This bundle is roughly equivalent to the following (generated) F<dist.ini>:
 
   [Authority]
   :version       = 1.005
+  authority      = cpan:RWSTAUNER
   do_metadata    = 1
   do_munging     = 1
   locate_comment = 0
@@ -582,10 +680,14 @@ This bundle is roughly equivalent to the following (generated) F<dist.ini>:
   [Readme]
 
   [ReadmeAnyFromPod]
-  :version = 0.120120
+  :version = 0.142180
   location = root
+  phase    = release
   type     = markdown
 
+  [CopyFilesFromRelease]
+  filename = LICENSE
+
   [AutoMetaResources]
   bugtracker.rt = 1
 
@@ -653,6 +755,7 @@ This bundle is roughly equivalent to the following (generated) F<dist.ini>:
   allow_dirty = Changes
   allow_dirty = README.mkdn
   allow_dirty = README.pod
+  allow_dirty = LICENSE
   commit_msg  = v%v%t%n%n%c
 
   [ConfirmRelease]
